@@ -1,5 +1,5 @@
 /*  Zutils - Utilities dealing with compressed files
-    Copyright (C) 2009-2016 Antonio Diaz Diaz.
+    Copyright (C) 2009-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ const char * const format_names[num_formats] = { "bz2", "gz", "lz", "xz" };
 const char * const simple_extensions[num_formats] =
   { ".bz2", ".gz", ".lz", ".xz" };
 const int format_order[num_formats] =
-  { fmt_lz, fmt_bz2, fmt_gz, fmt_xz };		// search order
+  { fmt_lz, fmt_bz2, fmt_gz, fmt_xz };			// search order
 
 bool enabled_format( const int format_index );
 void parse_format_list( const std::string & arg );
@@ -49,6 +49,8 @@ void show_help_addr();
 void show_version();
 void show_error( const char * const msg, const int errcode = 0,
                  const bool help = false );
+void show_file_error( const char * const filename, const char * const msg,
+                      const int errcode = 0 );
 void show_error2( const char * const msg, const char * const name );
 void internal_error( const char * const msg );
 void show_close_error( const char * const prog_name = "data feeder" );
