@@ -1,5 +1,5 @@
 /*  Zcat - decompress and concatenate files to standard output
-    Copyright (C) 2010-2016 Antonio Diaz Diaz.
+    Copyright (C) 2010-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ void show_help()
                "compressed, its decompressed content is used. If a given file does not\n"
                "exist, and its name does not end with one of the known extensions, zcat\n"
                "tries the compressed file names corresponding to the supported formats.\n"
-               "\nIf no files are specified, or if a file is specified as '-', data is\n"
+               "\nIf no files are specified, or if a file is specified as '-', data are\n"
                "read from standard input, decompressed if needed, and sent to standard\n"
                "output. Data read from standard input must be of the same type; all\n"
                "uncompressed or all in the same compression format.\n"
@@ -233,7 +233,8 @@ int cat( int infd, const int format_index, const std::string & input_filename,
   uint8_t * const outbuf = new uint8_t[(4*buffer_size)+256];
   int retval = 0;
   Children children;
-  if( !set_data_feeder( &infd, children, format_index ) ) retval = 1;
+  if( !set_data_feeder( input_filename, &infd, children, format_index ) )
+    retval = 1;
   else
     retval = do_cat( infd, buffer_size, inbuf, outbuf,
                      input_filename, cat_options );
