@@ -1,5 +1,5 @@
 /*  Zutils - Utilities dealing with compressed files
-    Copyright (C) 2009-2015 Antonio Diaz Diaz.
+    Copyright (C) 2009-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 int readblock( const int fd, uint8_t * const buf, const int size );
 int writeblock( const int fd, const uint8_t * const buf, const int size );
-bool feed_data( const int infd, const int outfd,
+bool feed_data( const std::string & filename, const int infd, const int outfd,
                 const uint8_t * magic_data, const int magic_size );
 
 struct Children
@@ -26,7 +26,8 @@ struct Children
   pid_t pid[2];				// data feeder, compressor
   };
 bool good_status( const Children & children, const bool finished );
-bool set_data_feeder( int * const infdp, Children & children, int format_index );
+bool set_data_feeder( const std::string & filename, int * const infdp,
+                      Children & children, int format_index );
 
 // Returns format index or -1 if uncompressed
 //
